function get_epoch_sfcs, epoch_date, filt_a=filt_a, filt_b=filt_b, $
                                     boxnotes=boxnotes
;+
;Purpose: for a given date, and filter combination,
;         return the file names for all sfcs of that filter
;         combination in that epoch.
;
;History:
;   Circa Oct 2000 - Phil Shirts
;   9-Jan-2000 - S.L.Freeland - return null string if no SFC matches
;                               (previous stopped via 'message' )
;   8-May-2001 - S.L.Freeland - add a sort on output files
;                               (epoch 5 spans millenum = y2K non chronological)
;-

;INITIALIZE KEYWORD VALUES
;1.) FILTER VALUES
IF ( (1-keyword_set(filt_a)) AND (1-keyword_set(filt_b)) ) THEN $
   print, 'No filter chosen: Using default of filt_a=1;filt_b=2'
IF (1-keyword_set(filt_a)) THEN filt_a = 1
IF (1-keyword_set(filt_b)) THEN filt_b = 2

;Get filter failure epoch boundary information.
epoch_bound=[get_yo_dates(/entrance),ut_time(!stime)] 
num_epochs = n_elements(epoch_bound)

;Determine which filter-failure dates epoch_date is between.	
t_compare = ssw_time_compare(epoch_bound, epoch_date, /later)
later  = where((t_compare eq 1), num_gd_later)
earlier= where((t_compare eq 0), num_gd_earlier)

;GET SFC indices for the epoch corresponding to epoch_date
IF (num_gd_later gt 0 and num_gd_earlier gt 0) THEN BEGIN
   files_t=sel_filetimes(epoch_bound(earlier(n_elements(earlier)-1)),epoch_bound(later(0)),filter='sfc*',dir=get_logenv('DIR_SXT_SFC'))
ENDIF ELSE BEGIN
   message,'No observations are available for the time you provided'
ENDELSE

;Determine X-Y values of index files.
rd_xda,files_t,-1, index
xy_plot=sxt_cen(index)

;450:570,550:630
;ONLY PICK SFCS with offpoint less than delta_r pixels - is 511.5 the correct number here?
;   sfcs = where( (gt_filta(index) eq filt_a) AND (gt_filtb(index) eq filt_b) AND $ 
;                (ABS(xy_plot(0,*) -510.) LE 60. ) AND (ABS(xy_plot(1,*) -590.000) LE 40.0), n_good_sfcs) 
   sfcs = where( (gt_filta(index) eq filt_a) AND (gt_filtb(index) eq filt_b) , n_good_sfcs);

;
IF (n_good_sfcs gt 0) THEN BEGIN 
   files=files_t(sfcs) 
   files=files(sort(anytim(file2time(files,out='ecs'))))
ENDIF ELSE begin
   box_message,'No SFCs for this epoch/filter/pointing combination' 
   files=''
ENDELSE


return, files

end
