pro hxt_impulsiveness, index, data, duration, net_duration, impulsiveness,$
     infile=infile, event_time=event_time, deltat=deltat
; 
;+ 
;   Name: hxt_impulsivness
;
;   Input Parameters:
;      index, data  - hxt 'index,data' pair 
;
;   Output Parameters:
;      (index,data) - if INFILE or EVENT_TIME specified, these are updated
;      duration 
;      net_duration
;      impulsiveness
;
;   Keyword Parameters:
;      infile - optional hda file name (in lieu of index,data)
;      event_time - optional event time to check  
;                   (assumes all hda data online via cdrom/mag_disk) 
;      deltat - deltaT (minutes) between event time and index(0)
;               (only defined for EVENT_TIME input)
;
;   History:
;      20-Jan-2000 - Hugh Hudson - wrote hx_duration
;       9-Feb-2001 - S.L.Freeland - convert hx_duration to routine
;-

duration=fltarr(4)-1
net_duration=duration
impulsiveness=duration

case 1 of
   data_chk(infile,/string): begin
      if file_exist(infile) then rd_xda,infile,-1,index,data else begin 
         box_message,'File: ' + infile + ' does not exist, returing'
         return
      endelse
   endcase 
   keyword_set(event_time): begin
      hfiles=cdrom_files(day=gt_day(event_time,/string),/hda,/mag)
      time_window,event_time,t0,t1,out='ints'
      sfiles=sel_filetimes(t0,t1,hfiles,/one_before) 
      box_message,sfiles(0)
      if sfiles(0) eq '' then begin 
         box_message,'No HDA file found'
         return
      endif
      rd_xda,sfiles(0),-1,index,data
      deltat=ssw_deltat(index(0),ref=t0,/min)
      if deltat gt 60 then box_message,'Warning: DeltaT(EVENT:INDEX) > 60 min'
   endcase
endcase
; =================================================================
;  following is verbatim from Hugh Hudson dx_duration main program 
cts = ave_cts(index,data,time=time)
nn = n_elements(index)
cts = reform(rebin(cts,4,1,nn))
time = reform(rebin(time,1,nn))
dur = fltarr(4)
net_dur = fltarr(4)
hxt_background, backs
for i = 0,3 do begin 
  chmax = max(cts(i,*)) 
  print,backs(i),chmax
  if chmax gt 4*backs(i) then begin
    excess = cts(i,*)-backs(i)
    exmax = max(excess)
    sshalf =  where(excess gt .5*exmax, n_ss) 
    net_dur(i) = n_ss*2.048
    dur(i) = max(int2secarr(index(sshalf)))
  endif 
endfor
impulsiveness = fltarr(4)
for i = 0,3 do begin
  if net_dur(i) ne 0 then impulsiveness(i) = dur(i)/net_dur(i)
endfor

;=============================================================
duration=dur
net_duration=net_dur
return
end
