pro sxt_flarepos, time0, time1, flares, $
    solar_diameter=solar_diameter, dcenter=decenter, $
    debug=debug, goes=goes, hxt_impulse=hxt_impulse
;+
;   Name: sxt_flarepos
;
;   Purpose: tag flare modes via sxtp center
;
;   Input Parameters:
;      time0, time1 - range of interest
;
;   Output Parameters:
;      flares - vector of structures 
;               1st sxt pfi obs record with ssw and position info added
;   
;-

get_utevent, time0, time1, fstart, fstop, /flare     ; flare times
delvarx,flares
nfs=n_elements(fstart)
dcenter=fltarr(nfs)-9999999
debug=keyword_set(debug)
hxt_impulse=keyword_set(hxt_impulse)

for i=0, nfs-1 do begin 
   delvarx,sxtp
   if ssw_deltat(fstart(i),fstop(i),/min) gt 4 then begin 
   get_utevent, fstart(i), fstop(i), sxtp, /sxtp       ; observing log 
   if data_chk(sxtp,/struct) then begin 
      ssflare=struct_where(sxtp,test=['gt_dp_mode=9',$ ; filter{
           'gt_filtb=2,3','gt_filta=1'],fcnt)
      if fcnt eq 0 then begin
         box_message,'No Al.1 or AlMg - trying heavier stuff..'
         ssflare=struct_where(sxtp,test=['gt_dp_mode=9',$
           'gt_filtb=4','gt_filta=1'],fcnt)
      endif 
      if fcnt gt 0 then begin 
         suninfo=get_sun(sxtp(ssflare(0)),sd=radius)
         ssw=struct2ssw(sxtp(ssflare(0)))             ; add ssw stds
         ssw=add_tag(ssw,0.,'dlimb')                   ; add tags
         ssw=add_tag(ssw,'','goeslev')
         ssw=add_tag(ssw,0L,'goesdt')
         ssw=add_tag(ssw,0.,'goesmin')
         ssw=add_tag(ssw,0.,'goesmax')
         if keyword_set(hxt_impulse) then begin 
            ssw=add_tag(ssw,fltarr(4),'hxt_dur')
            ssw=add_tag(ssw,fltarr(4),'hxt_netdur')
            ssw=add_tag(ssw,fltarr(4),'hxt_impulsiveness')
         endif
         xc=gt_tagval(ssw,/xcen)
         yc=gt_tagval(ssw,/ycen)
         dc=sqrt(xc^2. + yc^2.)                        ; fov:suncenter
         dcenter(i)=dc
         ssw.dlimb=radius-dc                           ; fov:limb
         if keyword_set(goes) then begin 
            time_window,sxtp(ssflare),t0,t1
            gev=get_gev(anytim(t0,/utc_int),anytim(t1,/utc_int))
            ss=tim2dset(gev,sxtp(ssflare(0)),delta=delta)
            delvarx,class
            decode_gev,gev(ss),class=class
            if n_elements(class) gt 0 then ssw.goeslev=class(0) 
            ssw.goesdt=delta  
            delvarx,gxd
            rd_gxd,t0,t1,gxd,/one,/goes7
            if not data_chk(gxd,/struct) then rd_gxd,t0,t1,gxd,/one,/goes8
            if not data_chk(gxd,/struct) then rd_gxd,t0,t1,gxd,/one,/goes10
            if data_chk(gxd,/struct) then begin 
               ssw.goesmin=min(gxd.lo)
               ssw.goesmax=max(gxd.lo) 
           endif
         endif
         if keyword_set(hxt_impulse) then begin 
            hxt_impulsiveness, event_time=ssw, index,data, $
               hxt_dur, hxt_netdur, hxt_imp
            ssw.HXT_DUR=hxt_dur
            ssw.HXT_NETDUR=hxt_netdur
            ssw.HXT_IMPULSIVENESS=hxt_imp
         endif

         if n_elements(flares) eq 0 then flares=ssw else flares= $
                concat_struct(flares,ssw)

      endif else  begin
         box_message,'no flare mode in sxtp'
         if debug then stop,'no flare...'
      endelse

   endif else  begin
      box_message,'no spr observing records(?)'
      if debug then stop,' no spr???'
   endelse
   endif else box_message,'Flare mode < 4 minutes'
endfor

return
end




